@@ -13,14 +13,15 @@ use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_001'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub opt_spec {
     my ($self, $app) = @_;
 
-    return (
+    return ( $self->SUPER::opt_spec(),
+        [ 'noinit'  => 'Do not pull/update from VCS' ],
         [ 'sleep=i' => 'seconds to sleep before exiting' ],
     );
 }
@@ -32,13 +33,24 @@ sub validate_args {
 
     $self->SUPER::validate_args($opts, $args);
 
-    $self->usage_error('Sleep time must be positive integer')
-      if defined $opts->{sleep} && $opts->{sleep} < 1;
+    $self->usage_error('Arguments are not allowed') if @{ $args };
 
     return 1;
 }
 
 #------------------------------------------------------------------------------
+
+sub execute {
+    my ($self, $opts, $args) = @_;
+
+    $self->pinto->new_action_batch( %{$opts} );
+    $self->pinto->add_action('Nop', %{$opts} );
+    my $result = $self->pinto->run_actions();
+    return $result->is_success() ? 0 : 1;
+}
+
+#------------------------------------------------------------------------------
+
 1;
 
 
@@ -53,32 +65,7 @@ App::Pinto::Admin::Command::nop - initialize Pinto and exit
 
 =head1 VERSION
 
-version 0.040_001
-
-=head1 SYNOPSIS
-
-  pinto-admin --root=/some/dir nop [OPTIONS]
-
-=head1 DESCRIPTION
-
-This command is a no-operation.  It locks and initializes the
-repository, but does not perform any operations.  This is really only
-used for diagnostic purposes.  So don't worry about it too much.
-
-=head1 COMMAND ARGUMENTS
-
-None.
-
-=head1 COMMAND OPTIONS
-
-=over 4
-
-=item --sleep=N
-
-Directs L<Pinto> to sleep for N seconds before releasing the lock and
-exiting.  Default is 0.
-
-=back
+version 0.020
 
 =head1 AUTHOR
 
@@ -95,4 +82,3 @@ the same terms as the Perl 5 programming language system itself.
 
 
 __END__
-
