@@ -1,19 +1,18 @@
-# ABSTRACT: A no-op action
-
 package Pinto::Action::Nop;
 
+# ABSTRACT: A no-op action
+
 use Moose;
-use MooseX::StrictConstructor;
+
 use MooseX::Types::Moose qw(Int);
-use MooseX::MarkAsMethods ( autoclean => 1 );
+
+extends 'Pinto::Action';
+
+use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.09992_02'; # VERSION
-
-#------------------------------------------------------------------------------
-
-extends qw( Pinto::Action );
+our $VERSION = '0.020'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -25,16 +24,16 @@ has sleep => (
 
 #------------------------------------------------------------------------------
 
-sub execute {
+override execute => sub {
     my ($self) = @_;
 
-    if ( my $sleep = $self->sleep ) {
-        $self->notice("Process $$ sleeping for $sleep seconds");
-        sleep $self->sleep;
+    if ( my $sleep = $self->sleep() ) {
+        $self->logger->debug("Process $$ sleeping for $sleep seconds");
+        sleep $self->sleep();
     }
 
-    return $self->result;
-}
+    return 0;
+};
 
 #------------------------------------------------------------------------------
 
@@ -45,16 +44,11 @@ __PACKAGE__->meta->make_immutable();
 
 1;
 
-__END__
+
 
 =pod
 
-=encoding UTF-8
-
-=for :stopwords Jeffrey Ryan Thalhammer BenRifkah Fowler Jakob Voss Karen Etheridge Michael
-G. Bergsten-Buret Schwern Nikolay Martynov Oleg Gashev Steffen Schwigon
-Tommy Stanton Wolfgang Boris Kinkeldei Yanick Champoux brian d foy hesco
-popl Däppen Cory G Watson David Steinbrunner Glenn
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -62,7 +56,7 @@ Pinto::Action::Nop - A no-op action
 
 =head1 VERSION
 
-version 0.09992_02
+version 0.020
 
 =head1 DESCRIPTION
 
@@ -72,13 +66,16 @@ on them.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jeffrey Ryan Thalhammer.
+This software is copyright (c) 2011 by Imaginative Software Systems.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
